"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pasteNoUnintendedAnchors = void 0;
const isJsxIdentifier = (nodeName) => typeof (nodeName === null || nodeName === void 0 ? void 0 : nodeName.name) === 'string';
const isJsxAttributes = (attributes) => attributes.every((attr) => isJsxIdentifier(attr === null || attr === void 0 ? void 0 : attr.name));
const validHrefTags = ['Link', 'DocsAnchor', 'link'];
exports.pasteNoUnintendedAnchors = {
    defaultOptions: [],
    meta: {
        type: 'problem',
        messages: {
            noUnintendedPasteAnchors: 'Use a <Link> or <DocsAnchor> when trying to provide links, or wrap this component in a <Link> with the `legacyBehavior` prop',
        },
        docs: {
            description: "Using the `href` prop directly on components other than Next.js' <Link> or <DocsAnchor> can cause unintended page reloads and bad user experience. If this specific component is _absolutely_ necessary, consider wrapping it in a <Link> with legacyBehavior to preserve in-app navigation behavior.",
            recommended: 'warn',
            url: 'https://nextjs.org/docs/pages/api-reference/components/link',
        },
        schema: [], // no options
    },
    create(context) {
        return {
            JSXOpeningElement: (node) => {
                if (!isJsxIdentifier(node.name) || !isJsxAttributes(node.attributes))
                    return;
                if (validHrefTags.includes(node.name.name))
                    return;
                const hasHrefProp = node.attributes.some((attr) => attr.name.name === 'href');
                // Edge case: it's valid/necessary in some cases to use the href prop _if_ component is the direct child of a Link, ex Anchor, and it is using legacy behavior
                const lastAncestor = context.getAncestors().at(-2);
                const isWrappedByLegacyNextLink = (lastAncestor === null || lastAncestor === void 0 ? void 0 : lastAncestor.type) === 'JSXElement' &&
                    isJsxIdentifier(lastAncestor.openingElement.name) &&
                    lastAncestor.openingElement.name.name === 'Link' &&
                    isJsxAttributes(lastAncestor.openingElement.attributes) &&
                    lastAncestor.openingElement.attributes.some((attr) => attr.name.name === 'legacyBehavior');
                if (hasHrefProp && !isWrappedByLegacyNextLink) {
                    context.report({
                        node,
                        messageId: 'noUnintendedPasteAnchors',
                    });
                }
            },
        };
    },
};
//# sourceMappingURL=paste-no-unintended-anchors.js.map